@@ -35,6 +35,7 @@
 #include "seahorse-servers.h"
 
 #include "seahorse-object-list.h"
+#include "seahorse-place.h"
 #include "seahorse-progress.h"
 #include "seahorse-registry.h"
 #include "seahorse-util.h"
@@ -418,7 +419,7 @@ parse_hkp_index (const gchar *response)
 
 				key = seahorse_pgp_key_new ();
 				keys = g_list_prepend (keys, key);
-				g_object_set (key, "flags", flags, NULL);
+				g_object_set (key, "object-flags", flags, NULL);
 
 				/* Add all the info to the key */
 				subkey = seahorse_pgp_subkey_new ();
